==> haskell-pandoc-types-1.23.1-153-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-pandoc-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pandoc-types
version:              1.23.1
visibility:           public
id:                   pandoc-types-1.23.1-2Af65ACjfKtCfKJLbmCXaX
key:                  pandoc-types-1.23.1-2Af65ACjfKtCfKJLbmCXaX
license:              BSD-3-Clause
copyright:            (c) 2006-2023 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://pandoc.org/
synopsis:             Types for representing a structured document
description:
    @Text.Pandoc.Definition@ defines the '\''Pandoc'\'' data
    structure, which is used by pandoc to represent
    structured documents.  This module used to live
    in the pandoc package, but starting with pandoc 1.7, it
    has been split off, so that other packages can use it
    without drawing in all of pandoc'\''s dependencies, and
    pandoc itself can depend on packages (like citeproc-hs)
    that use them.

    @Text.Pandoc.Builder@ provides functions for building
    up @Pandoc@ structures programmatically.

    @Text.Pandoc.Generic@ provides generic functions for
    manipulating Pandoc documents.

    @Text.Pandoc.Walk@ provides faster, nongeneric functions
    for manipulating Pandoc documents.

    @Text.Pandoc.JSON@ provides functions for serializing
    and deserializing a @Pandoc@ structure to and from JSON.

category:             Text
abi:                  79baf5b3143b4f05e772c81cddb8712e
exposed:              True
exposed-modules:
    Text.Pandoc.Arbitrary Text.Pandoc.Builder Text.Pandoc.Definition
    Text.Pandoc.Generic Text.Pandoc.JSON Text.Pandoc.Walk

hidden-modules:       Paths_pandoc_types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/pandoc-types-1.23.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pandoc-types-1.23.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pandoc-types-1.23.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pandoc-types
hs-libraries:         HSpandoc-types-1.23.1-2Af65ACjfKtCfKJLbmCXaX
depends:
    QuickCheck-2.15.0.1-5wgMd498nCWIkHPGslLJlo
    aeson-2.1.2.1-3HLieqpkeG06w6MDAYdLLk base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0 ghc-prim-0.9.1
    syb-0.7.3-C5AaeelSWDKGvBUWTjIxkt text-2.0.2 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-pandoc-types/html/pandoc-types.haddock

haddock-html:         /usr/share/doc/haskell-pandoc-types/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pandoc-types-1.23.1-159-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-pandoc-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pandoc-types
version:              1.23.1
visibility:           public
id:                   pandoc-types-1.23.1-4krSuOvdDvuCnL51s2n70g
key:                  pandoc-types-1.23.1-4krSuOvdDvuCnL51s2n70g
license:              BSD-3-Clause
copyright:            (c) 2006-2023 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://pandoc.org/
synopsis:             Types for representing a structured document
description:
    @Text.Pandoc.Definition@ defines the '\''Pandoc'\'' data
    structure, which is used by pandoc to represent
    structured documents.  This module used to live
    in the pandoc package, but starting with pandoc 1.7, it
    has been split off, so that other packages can use it
    without drawing in all of pandoc'\''s dependencies, and
    pandoc itself can depend on packages (like citeproc-hs)
    that use them.

    @Text.Pandoc.Builder@ provides functions for building
    up @Pandoc@ structures programmatically.

    @Text.Pandoc.Generic@ provides generic functions for
    manipulating Pandoc documents.

    @Text.Pandoc.Walk@ provides faster, nongeneric functions
    for manipulating Pandoc documents.

    @Text.Pandoc.JSON@ provides functions for serializing
    and deserializing a @Pandoc@ structure to and from JSON.

category:             Text
abi:                  e71ea38b4be8e09de918436865d10d74
exposed:              True
exposed-modules:
    Text.Pandoc.Arbitrary Text.Pandoc.Builder Text.Pandoc.Definition
    Text.Pandoc.Generic Text.Pandoc.JSON Text.Pandoc.Walk

hidden-modules:       Paths_pandoc_types
import-dirs:          /usr/lib/ghc-9.6.7.20250817/site-local/pandoc-types-1.23.1
library-dirs:         /usr/lib/ghc-9.6.7.20250817/site-local/pandoc-types-1.23.1
library-dirs-static:  /usr/lib/ghc-9.6.7.20250817/site-local/pandoc-types-1.23.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pandoc-types
hs-libraries:         HSpandoc-types-1.23.1-4krSuOvdDvuCnL51s2n70g
depends:
    QuickCheck-2.15.0.1-Lq4ECkPzV8iDkKvRhPZIAs
    aeson-2.2.0.0-C0AkopVKntgCgZgm8TP6Wj base-4.18.3.0
    bytestring-0.11.5.4 containers-0.6.7 deepseq-1.4.8.1
    ghc-prim-0.10.0 syb-0.7.3-4faDNy9a4q18QDGKds5is3 text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-pandoc-types/html/pandoc-types.haddock

haddock-html:         /usr/share/doc/haskell-pandoc-types/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
